import 'package:flutter/material.dart';
import 'package:router_management/src/custom_page_transition.dart';

///CustomPageDialog class create a fullscreenDialog
class CustomPageDialog<T> extends PopupRoute<T> {
  final WidgetBuilder builder;
  final RouteTransitionsBuilder transitionsBuilder;

  CustomPageDialog({
    @required this.builder,
    this.transitionsBuilder,
    RouteSettings settings,
  })  : assert(builder != null),
        super(settings: settings);

  @override
  Color get barrierColor => Colors.black54;

  @override
  bool get barrierDismissible => false;

  @override
  String get barrierLabel => null;

  @override
  Widget buildPage(BuildContext context, Animation<double> animation,
      Animation<double> secondaryAnimation) {
    final child = builder(context);
    assert(child != null);
    return Semantics(
      scopesRoute: true,
      explicitChildNodes: true,
      child: child,
    );
  }

  @override
  Widget buildTransitions(BuildContext context, Animation<double> animation,
      Animation<double> secondaryAnimation, Widget child) {
    return transitionsBuilder != null
        ? transitionsBuilder(context, animation, secondaryAnimation, child)
        : CustomPageTransition(
            animation: animation,
            secondaryAnimation: secondaryAnimation,
            fullscreenDialog: true,
            child: child,
          );
  }

  @override
  Duration get transitionDuration => const Duration(milliseconds: 250);
}

///CustomPageRoute class create a page route with custom animations and durations
class CustomPageRoute<T> extends PageRoute<T> {
  final WidgetBuilder builder;
  final RouteTransitionsBuilder transitionsBuilder;

  CustomPageRoute({
    @required this.builder,
    this.maintainState = true,
    this.transitionDuration = const Duration(milliseconds: 500),
    this.transitionsBuilder,
    RouteSettings settings,
  })  : assert(builder != null),
        super(settings: settings, fullscreenDialog: false);

  @override
  final bool maintainState;

  @override
  Color get barrierColor => null;

  @override
  String get barrierLabel => null;

  @override
  Widget buildPage(BuildContext context, Animation<double> animation,
      Animation<double> secondaryAnimation) {
    final child = builder(context);
    assert(child != null);
    return Semantics(
      scopesRoute: true,
      explicitChildNodes: true,
      child: child,
    );
  }

  @override
  Widget buildTransitions(BuildContext context, Animation<double> animation,
      Animation<double> secondaryAnimation, Widget child) {
    return transitionsBuilder != null
        ? transitionsBuilder(context, animation, secondaryAnimation, child)
        : CustomPageTransition(
            animation: CurvedAnimation(
              curve: Curves.linearToEaseOut,
              reverseCurve: Curves.ease,
              parent: animation,
            ),
            secondaryAnimation: CurvedAnimation(
              parent: secondaryAnimation,
              curve: Curves.linearToEaseOut,
              reverseCurve: Curves.easeInToLinear,
            ),
            child: child,
          );
  }

  @override
  final Duration transitionDuration;
}
