import 'package:flutter/material.dart';

///CustomPageTransition a class for creating custom page transitions animations
class CustomPageTransition extends StatelessWidget {
  final Animation<double> animation, secondaryAnimation;
  final Widget child;
  final bool fullscreenDialog;

  const CustomPageTransition({
    Key key,
    @required this.animation,
    @required this.secondaryAnimation,
    this.fullscreenDialog = false,
    @required this.child,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final textDirection = Directionality.of(context);
    return SlideTransition(
      transformHitTests: false,
      textDirection: textDirection,
      position: Tween<Offset>(
        begin: Offset.zero,
        end: fullscreenDialog ? Offset.zero :  const Offset(-1.0 / 3.0, 0.0),
      ).animate(secondaryAnimation),
      child: SlideTransition(
        position: Tween<Offset>(
          begin: fullscreenDialog
              ? const Offset(0.0, 1.0)
              : const Offset(1.0, 0.0),
          end: Offset.zero,
        ).animate(animation),
        child: DecoratedBoxTransition(
          position: DecorationPosition.foreground,
          decoration: DecorationTween(
            begin: const BoxDecoration(color: Colors.transparent),
            end: const BoxDecoration(color: Colors.black54),
          ).animate(secondaryAnimation),
          child: FadeTransition(
            opacity:
                animation.status == AnimationStatus.reverse || fullscreenDialog
                    ? animation
                    : const AlwaysStoppedAnimation<double>(1.0),
            child: child,
          ),
        ),
      ),
    );
  }
}
