import 'dart:collection';
import 'dart:io';

import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:router_management/src/custom_page_route.dart';
import 'package:router_management/src/page_settings.dart';

///RouterController class manage routes of the whole application
class RouterController {
  final _routes = LinkedHashMap<String, PageSettings>();

  void addRoute(
    String name,
    WidgetBuilder builder, {
    bool useNativeTransitions = true,
    bool fullscreenDialog = false,
    Duration transitionDuration = const Duration(milliseconds: 500),
    RouteTransitionsBuilder transitionsBuilder,
  }) {
    _routes[name] = PageSettings(builder, useNativeTransitions,
        fullscreenDialog, transitionDuration, transitionsBuilder);
  }

  Route onGenerateRoute(RouteSettings settings) {
    final route = _routes[settings.name];
    if (route == null) {
      return null;
    } else if (!route.useNativeTransitions || kIsWeb) {
      if (!route.fullscreenDialog) {
        return CustomPageRoute(
          builder: route.builder,
          settings: settings,
          transitionDuration: route.transitionDuration,
          transitionsBuilder: route.transitionsBuilder,
        );
      } else {
        return CustomPageDialog(
          builder: route.builder,
          settings: settings,
          transitionsBuilder: route.transitionsBuilder,
        );
      }
    } else if (Platform.isIOS) {
      return CupertinoPageRoute(
        builder: route.builder,
        fullscreenDialog: route.fullscreenDialog,
        settings: settings,
      );
    } else {
      return MaterialPageRoute(
        builder: route.builder,
        settings: settings,
        fullscreenDialog: route.fullscreenDialog,
      );
    }
  }
}
